@@ -96,7 +96,7 @@ my $configure_hadoop=sub {
          &Net::FullAuto::FA_Core::cleanup;
       }
       ($stdout,$stderr)=$handle->cmd("wget -qO- ".
-         "$hadoop_mirror/hadoop/common/stable");
+         "${hadoop_mirror}stable");
       my $flag=0;
       foreach my $line (split "\n",$stdout) {
          chomp($line);
@@ -144,12 +144,12 @@ END
    foreach my $dc (0..2) {
       ($stdout,$stderr,$exitcode)=$handle->cmd(
          "sudo wget --random-wait --progress=dot ".
-         "$hadoop_mirror/hadoop/common/stable/$targz 2>&1",
+         "${hadoop_mirror}stable/$targz 2>&1",
          '__display__');
       print "wget ERROR: $stderr\n" if $stderr;
       ($stdout,$stderr)=$handle->cmd(
          "sudo wget --random-wait --progress=dot ".
-         "$hadoop_mirror/hadoop/common/stable/$md5 2>&1",
+         "${hadoop_mirror}stable/$md5 2>&1",
          '__display__');
       ($stdout,$stderr)=$handle->cmd("cat $md5");
       my $checksum=$stdout;
@@ -190,7 +190,7 @@ END
    my $id=$main::aws->{$server_type}->[$cnt]->[0]->{InstanceId};
    my ($hash,$output)=('','');
    my $c="aws ec2 describe-instances --instance-ids $id 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    my $pdns=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicDnsName};
    my $pip=$hash->{Reservations}->[0]->{Instances}->[0]->{PrivateIpAddress};
    ($stdout,$stderr)=$handle->cmd("sudo hostname $pdns");
@@ -265,7 +265,7 @@ END
       "sudo mkdir -p /opt/$targz/hdfstmp",'__display__');
    my $master=$main::aws->{$server_type}->[0]->[0]->{InstanceId};
    $c="aws ec2 describe-instances --instance-ids $master 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    my $mdns=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicDnsName};
    my $ad='NL<property>NL<name>fs.default.name</name>NL'. # NL is newline
        '<value>hdfs://'.$mdns.':8020</value>NL'.
@@ -320,7 +320,7 @@ END
       foreach my $inum (0..3) {
          my $inid=$main::aws->{$server_type}->[$inum]->[0]->{InstanceId};
          $c="aws ec2 describe-instances --instance-ids $inid 2>&1";
-         ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+         ($hash,$output,$error)=run_aws_cmd($c);
          my $dns=$hash->{Reservations}->[0]->{Instances}->[0]
                  ->{PublicDnsName};
          push @dns,$dns;
@@ -445,32 +445,32 @@ my $standup_hadoop=sub {
          "--group-names $n";
    my $u=($os eq 'Ubuntu')?'ubuntu':'';
    my ($hash,$output,$error)=('','','');
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error;
    my $cidr=$hash->{SecurityGroups}->[0]->{IpPermissions}
             ->[0]->{IpRanges}->[0]->{CidrIp};
    $c='aws ec2 create-security-group --group-name '.
       'HadoopSecurityGroup --description '.
       '"Hadoop.Apache.org Security Group" 2>&1';
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name HadoopSecurityGroup --protocol '.
       'tcp --port 22 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name HadoopSecurityGroup --protocol '.
       'tcp --port 0-65535 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    $c='aws ec2 authorize-security-group-ingress '.
       '--group-name HadoopSecurityGroup --protocol '.
       'icmp --port -1 --cidr '.$cidr." 2>&1";
-   ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
+   ($hash,$output,$error)=run_aws_cmd($c);
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    my $cnt=0;
