@@ -42,7 +42,7 @@ use Net::FullAuto::FA_Core qw[$localhost];
 use File::HomeDir;
 my $home_dir=File::HomeDir->my_home.'/';
 my $username=getlogin || getpwuid($<);
-my $do;my $ad;my $prompt;
+my $do;my $ad;my $prompt;my $public_ip='';
 
 my $configure_fullautoapi=sub {
 
@@ -309,6 +309,26 @@ if ($do==1) {
    #($stdout,$stderr)=$handle->cmd("rm -rvf master.zip",'__display__');
    #($stdout,$stderr)=$handle->cmd("sudo rabbitmq-server -detached",
    #   '__display__');
+
+   # TEST FOR AMAZON EC2 INSTANCE
+   #($stdout,$stderr)=$handle->cmd("wget -qO- ".
+   #   "wget http://169.254.169.254/latest/meta-data/public-ipv4");
+   #$public_ip=$stdout if $stdout=~/^\d+\.\d+\.\d+\.\d+\s*/s;
+
+   #unless ($public_ip) {
+      ($stdout,$stderr)=$handle->cmd("wget -qO- http://icanhazip.com");
+      $public_ip=$stdout if $stdout=~/^\d+\.\d+\.\d+\.\d+\s*/s;
+   #}
+   unless ($public_ip) {
+      require Sys::Hostname;
+      import Sys::Hostname;
+      require Socket;
+      import Socket;
+      my($addr)=inet_ntoa((gethostbyname(Sys::Hostname::hostname))[4]);
+      $public_ip=$addr if $addr=~/^\d+\.\d+\.\d+\.\d+\s*/s;
+   }
+   chomp($public_ip);
+   $public_ip='localhost' unless $public_ip;
    unless ($^O eq 'cygwin') {
       ($stdout,$stderr)=$handle->cmd(
          "wget --random-wait --progress=dot ".
@@ -472,8 +492,8 @@ print "DOING NGINX\n";
                   "--with-http_ssl_module --with-pcre=objs/lib/$pcre ".
                   "--with-zlib=objs/lib/$zlib";
    ($stdout,$stderr)=$handle->cmd($make_nginx,'__display__');
-   ($stdout,$stderr)=$handle->cmd("make install",'__display__');
-   ($stdout,$stderr)=$handle->cmd("sed -i 's/1024/64/' ".
+   ($stdout,$stderr)=$handle->cmd("${sudo}make install",'__display__');
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i 's/1024/64/' ".
       "/usr/local/nginx/nginx.conf");
    $ad="            include fastcgi_params;%NL%".
        "            fastcgi_pass localhost:3003;";
@@ -482,16 +502,17 @@ sed -i '1,/location/ {/location/a\\\
 $ad
 }' /usr/local/nginx/nginx.conf
 END
-   $handle->cmd_raw($ad);
+   $handle->cmd_raw("${sudo}$ad");
+   ($stdout,$stderr)=$handle->cmd("${sudo}chmod 755 $home_dir");
    $ad='%NL%        location /static {'.
-       '%NL%            root /home/Administrator/FullAutoAPI/root;'.
+       "%NL%            root ${home_dir}FullAutoAPI/root;".
        '%NL%        }%NL%%NL%';
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/404/a$ad\' /usr/local/nginx/nginx.conf");
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
        "/usr/local/nginx/nginx.conf");
-   ($stdout,$stderr)=$handle->cmd("sed -i 's/SCRIPT_NAME/PATH_INFO/' ".
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i 's/SCRIPT_NAME/PATH_INFO/' ".
       "/usr/local/nginx/fastcgi_params");
    $ad='# Catalyst requires setting PATH_INFO (instead of SCRIPT_NAME)'.
        ' to \$fastcgi_script_name';
@@ -503,7 +524,7 @@ END
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
        "/usr/local/nginx/fastcgi_params");
-   ($stdout,$stderr)=$handle->cmd('/usr/local/nginx/nginx');
+   ($stdout,$stderr)=$handle->cmd("${sudo}/usr/local/nginx/nginx");
 }
 $do=0;
 if ($do==1) {
@@ -527,7 +548,7 @@ if ($do==1) {
    unless ($stderr) {
       print(qq{ + CHECKSUM Test for $go *PASSED* \n});
    } else {
-      ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $go",'__display__');
+      ($stdout,$stderr)=$handle->cmd("${sudo}rm -rvf $go",'__display__');
       print "FATAL ERROR! : CHECKSUM Test for $go *FAILED* ";
       &Net::FullAuto::FA_Core::cleanup;
    }
@@ -2298,7 +2319,7 @@ END
    }
    sleep 15;
    print "\n   ACCESS CATALYST REST EXAMPLE AT:\n\n",
-         " http://localhost\n";
+         " http://$public_ip\n";
    my $thanks=<<'END';
 
      ______                  _    ,
